"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Typegen = void 0;
const core_1 = require("@oclif/core");
const core_2 = require("@oclif/core");
const definition_1 = require("../common/definition");
const commonFlags = require("../common/flags");
const openapi_client_axios_typegen_1 = require("openapi-client-axios-typegen");
class Typegen extends core_2.Command {
    async run() {
        const { args, flags } = await this.parse(Typegen);
        const { dereference, validate, bundle, header, root } = flags;
        const definition = (0, definition_1.resolveDefinition)(args.definition);
        if (!definition) {
            this.error('Please load a definition file', { exit: 1 });
        }
        let document;
        try {
            document = await (0, definition_1.parseDefinition)({
                definition,
                dereference,
                bundle,
                validate,
                inject: flags.inject,
                excludeExt: flags === null || flags === void 0 ? void 0 : flags['exclude-ext'],
                removeUnreferenced: flags === null || flags === void 0 ? void 0 : flags['remove-unreferenced'],
                strip: flags.strip,
                servers: flags.server,
                header,
                root,
            });
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        const [imports, schemaTypes, operationTypings, _banner, aliases] = await (0, openapi_client_axios_typegen_1.generateTypesForDocument)(document, { transformOperationName: (name) => name });
        if (flags.banner) {
            this.log(flags.banner + '\n');
        }
        this.log([
            imports,
            schemaTypes,
            operationTypings,
        ].join('\n'));
        if (flags['type-aliases'] && aliases) {
            this.log(`\n${aliases}`);
        }
    }
}
exports.Typegen = Typegen;
Typegen.description = 'Generate types from openapi definition';
Typegen.examples = [
    `$ openapi typegen ./openapi.yml > openapi.d.ts`,
];
Typegen.flags = {
    ...commonFlags.help(),
    ...commonFlags.parseOpts(),
    banner: core_1.Flags.string({
        char: 'b',
        description: 'include a banner comment at the top of the generated file'
    }),
    ['type-aliases']: core_1.Flags.boolean({
        char: 'A',
        description: 'Generate module level type aliases for schema components defined in spec',
        default: true,
        allowNo: true,
    }),
};
Typegen.args = {
    definition: core_2.Args.string({
        description: 'input definition file'
    })
};
